@@ -1,3 +1,21 @@
+/*****************************************************************************
+ * Copyright: 2011 Michael Zanetti <mzanetti@kde.org>                        *
+ *                                                                           *
+ * This program is free software: you can redistribute it and/or modify      *
+ * it under the terms of the GNU General Public License as published by      *
+ * the Free Software Foundation, either version 3 of the License, or         *
+ * (at your option) any later version.                                       *
+ *                                                                           *
+ * This program is distributed in the hope that it will be useful,           *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
+ * GNU General Public License for more details.                              *
+ *                                                                           *
+ * You should have received a copy of the GNU General Public License         *
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ ****************************************************************************/
+
 #include "albums.h"
 #include "xbmcconnection.h"
 
@@ -8,20 +26,21 @@
 #include "playlist.h"
 
 Albums::Albums(int artistId, XbmcModel *parent) :
-    XbmcModel(parent),
+    XbmcLibrary(parent),
     m_artistId(artistId)
 {
     QVariantMap params;
     if(artistId != -1) {
       params.insert("artistid", artistId);
     }
-    QVariantList fields;
-    fields.append("artist");
-    params.insert("fields", fields);
+    QVariantList properties;
+    properties.append("artist");
+    params.insert("properties", properties);
 
     QVariantMap sort;
     sort.insert("method", "label");
     sort.insert("order", "ascending");
+    sort.insert("ignorearticle", true);
     params.insert("sort", sort);
     m_request = XbmcConnection::sendCommand("AudioLibrary.GetAlbums", params);
     connect(XbmcConnection::notifier(), SIGNAL(responseReceived(int,QVariantMap)), SLOT(responseReceived(int,QVariantMap)));
@@ -78,11 +97,10 @@ XbmcModel* Albums::enterItem(int index)
 void Albums::playItem(int index)
 {
     AudioPlaylistItem pItem;
-    pItem.setArtistId(m_artistId);
     pItem.setAlbumId(m_list.at(index)->data(RoleAlbumId).toInt());
     Xbmc::instance()->audioPlayer()->playlist()->clear();
     Xbmc::instance()->audioPlayer()->playlist()->addItems(pItem);
-    Xbmc::instance()->audioPlayer()->playlist()->playItem(0);
+    Xbmc::instance()->audioPlayer()->playItem(0);
 }
 
 void Albums::addToPlaylist(int index)
